@@ -64,9 +64,9 @@
 	    0
 	    (if (= mn 0)
 		1
-		(let* ((mx (max k (- n k)))
-		       (cnk (+ 1 mx)))
-		  (do ((i 2 (+ i 1)))
+		(let ((mx (max k (- n k))))
+		  (do ((cnk (+ 1 mx))
+		       (i 2 (+ i 1)))
 		      ((> i mn) cnk)
 		    (set! cnk (/ (* cnk (+ mx i)) i))))))))))
     
@@ -74,10 +74,9 @@
 
 ;;; --------------------------------------------------------------------------------
 ;;; from Numerical Recipes
-(define (plgndr l m x)			;Legendre polynomial P m/l (x), m and l integer
-					;0 <= m <= l and -1<= x <= 1 (x real)
-  (if (or (< m 0) 
-	  (> m l) 
+(define (plgndr L m x)			;Legendre polynomial P m/L (x), m and L integer
+					;0 <= m <= L and -1<= x <= 1 (x real)
+  (if (or (not (<= 0 m L)) 
 	  (> (abs x) 1.0))
       (snd-error "invalid arguments to plgndr")
       (let ((pmm 1.0)
@@ -91,20 +90,19 @@
 		  ((> i m))
 		(set! pmm (* (- pmm) fact somx2))
 		(set! fact (+ fact 2.0)))))
-	(if (= l m) 
+	(if (= L m) 
 	    pmm
 	    (let ((pmmp1 (* x pmm (+ (* 2 m) 1))))
-	      (if (= l (+ m 1)) 
+	      (if (= L (+ m 1)) 
 		  pmmp1
-		  (let ((pk 0.0)) ; NR used "ll" which is unreadable
-		    (do ((k (+ m 2) (+ k 1)))
-			((> k l))
-		      (set! pk (/ (- (* x (- (* 2 k) 1) pmmp1) 
-				      (* (+ k m -1) pmm)) 
-				   (- k m)))
-		      (set! pmm pmmp1)
-		      (set! pmmp1 pk))
-		    pk)))))))
+		  (do ((pk 0.0) ; NR used "ll" which is unreadable
+		       (k (+ m 2) (+ k 1)))
+		      ((> k L) pk)
+		    (set! pk (/ (- (* x (- (* 2 k) 1) pmmp1) 
+				   (* (+ k m -1) pmm)) 
+				(- k m)))
+		    (set! pmm pmmp1)
+		    (set! pmmp1 pk))))))))
 
 
 ;;; A&S (bessel.lisp)
@@ -157,20 +155,22 @@
   (set! alpha (max alpha -0.5))
   (cond ((= n 0)       1.0)
 	((= alpha 0.0) (* (/ 2.0 n) (cos (* n x))))           ; maxima and A&S 22.3.14 (gsl has bogus values here)
-	((= n 1)       (* 2 alpha x))                         ; G&R 8.93(2)
-	((= n 2)       (- (* 2 alpha (+ alpha 1) x x) alpha)) ; G&R 8.93(3)
 	(else
-	 (let ((fn1 (* 2 x alpha))
-	       (fn 0.0)
-	       (fn2 1.0))
-	   (if (= n 1)
-	       fn1
-	       (do ((k 2 (+ k 1))
-		    (k0 2.0 (+ k0 1.0)))
-		   ((> k n) fn)
-		 (set! fn (/ (- (* 2 x fn1 (+ k alpha -1.0)) (* fn2 (+ k (* 2 alpha) -2.0))) k0))
-		 (set! fn2 fn1)
-		 (set! fn1 fn)))))))
+	 (case n
+	   ((1)       (* 2 alpha x))                          ; G&R 8.93(2)
+	   ((2)       (- (* 2 alpha (+ alpha 1) x x) alpha))  ; G&R 8.93(3)
+	   (else
+	    (let ((fn1 (* 2 x alpha))
+		  (fn 0.0000)
+		  (fn2 1.0000))
+	      (if (= n 1)
+		  fn1
+		  (do ((k 2 (+ k 1))
+		       (k0 2.0 (+ k0 1.0)))
+		      ((> k n) fn)
+		    (set! fn (/ (- (* 2 x fn1 (+ k alpha -1.0)) (* fn2 (+ k (* 2 alpha) -2.0))) k0))
+		    (set! fn2 fn1)
+		    (set! fn1 fn)))))))))
 
 ;;; (with-sound (:scaled-to 0.5) (do ((i 0 (+ i 1)) (x 0.0 (+ x .1))) ((= i 10000)) (outa i (gegenbauer 15 (cos x) 1.0))))
 
@@ -374,57 +374,52 @@
 (define (Si x) 
   (if (>= x 1.0)
       (- (/ pi 2) (* (cos x) (aux-f x)) (* (sin x) (aux-g x)))
-    (let ((sum x)
-	  (fact 2.0)
-	  (one -1.0)
-	  (xs x)
-	  (x2 (* x x))
-	  (err .000001)
-	  (unhappy #t))
-      (do ((i 3.0 (+ i 2.0)))
-	  ((not unhappy))
+      (do ((sum x)
+	   (fact 2.0)
+	   (one -1.0)
+	   (xs x)
+	   (x2 (* x x))
+	   (err .000001)
+	   (unhappy #t)
+	   (i 3.0 (+ i 2.0)))
+	  ((not unhappy) sum)
 	(set! xs (/ (* one x2 xs) (* i fact)))
 	(set! one (- one))
 	(set! fact (+ 1 fact))
 	(set! xs (/ xs fact))
 	(set! unhappy (> (abs xs) err))
-	(set! sum (+ sum xs)))
-      sum)))
+	(set! sum (+ sum xs)))))
 
 (define (Ci x) 
   (if (>= x 1.0)
       (- (* (sin x) (aux-f x)) (* (cos x) (aux-g x)))
-    (let ((g .5772156649)
-	  (sum 0.0)
-	  (fact 1.0)
-	  (one -1.0)
-	  (xs 1.0)
-	  (x2 (* x x))
-	  (err .000001)
-	  (unhappy #t))
-      (do ((i 2.0 (+ i 2.0)))
-	  ((not unhappy))
+      (do ((g .5772156649)
+	   (sum 0.0)
+	   (fact 1.0)
+	   (one -1.0)
+	   (xs 1.0)
+	   (x2 (* x x))
+	   (err .000001)
+	   (unhappy #t)
+	   (i 2.0 (+ i 2.0)))
+	  ((not unhappy) 
+	   (+ g (log x) sum))
 	(set! xs (/ (* one x2 xs) (* i fact)))
 	(set! one (- one))
 	(set! fact (+ 1 fact))
 	(set! xs (/ xs fact))
 	(set! unhappy (> (abs xs) err))
-	(set! sum (+ sum xs)))
-      (+ g (log x) sum))))
+	(set! sum (+ sum xs)))))
 
 
 ;;; --------------------------------------------------------------------------------
 
 (define bernoulli3
-  (let ((saved-values (let ((v (make-vector 100 #f))
-			    (vals (vector 1 -1/2 1/6 0 -1/30 0 1/42 0 -1/30 0 5/66 0 -691/2730
-					  0 7/6 0 -3617/510 0 43867/798 0 -174611/330 0
-					  854513/138 0 -236364091/2730 0 8553103/6 0
-					  -23749461029/870 0 8615841276005/14322 0)))
-			(do ((i 0 (+ i 1)))
-			    ((= i 30))
-			  (set! (v i) (vals i)))
-			v)))
+  (let ((saved-values (copy #(1 -1/2 1/6 0 -1/30 0 1/42 0 -1/30 0 5/66 0 -691/2730
+			      0 7/6 0 -3617/510 0 43867/798 0 -174611/330 0
+			      854513/138 0 -236364091/2730 0 8553103/6 0
+			      -23749461029/870 0 8615841276005/14322 0)
+			    (make-vector 100 #f))))
     (lambda (n)
       (if (number? (saved-values n))
 	  (saved-values n)
@@ -630,20 +625,20 @@
 	   
 	  ((or (= (modulo n 2) 0) (= (modulo n 3) 0) (= (modulo n 5) 0) (= (modulo n 7) 0) 
 	       (= (modulo n 17) 0) (= (modulo n 13) 0) (= (modulo n 257) 0) (= (modulo n 11) 0))
-	   (let ((divisor (cond ((= (modulo n 2) 0) 2)
-				((= (modulo n 3) 0) 3)
-				((= (modulo n 5) 0) 5)
-				((= (modulo n 7) 0) 7)
-				((= (modulo n 17) 0) 17)
-				((= (modulo n 13) 0) 13)
-				((= (modulo n 11) 0) 11)
-				(else 257))))
-	     (let ((val (sin-m*pi/n 1 (/ n divisor))))
-	       (and val
-		    `(let ((ex ,val))
-		       (/ (- (expt (+ (sqrt (- 1 (* ex ex))) (* 0+i ex)) (/ 1 ,divisor))
-			     (expt (- (sqrt (- 1 (* ex ex))) (* 0+i ex)) (/ 1 ,divisor)))
-			  0+2i))))))
+	   (let* ((divisor (cond ((= (modulo n 2) 0) 2)
+				 ((= (modulo n 3) 0) 3)
+				 ((= (modulo n 5) 0) 5)
+				 ((= (modulo n 7) 0) 7)
+				 ((= (modulo n 17) 0) 17)
+				 ((= (modulo n 13) 0) 13)
+				 ((= (modulo n 11) 0) 11)
+				 (else 257)))
+		  (val (sin-m*pi/n 1 (/ n divisor))))
+	     (and val
+		  `(let ((ex ,val))
+		     (/ (- (expt (+ (sqrt (- 1 (* ex ex))) (* 0+i ex)) (/ 1 ,divisor))
+			   (expt (- (sqrt (- 1 (* ex ex))) (* 0+i ex)) (/ 1 ,divisor)))
+			0+2i)))))
 	  (else #f))))
 
 #|
@@ -695,89 +690,85 @@
 
   (define (ihex x nhx chx)
     ;; This returns, in chx, the first nhx hex digits of the fraction of x.
-    (let ((y (abs x))
-	  (hx "0123456789ABCDEF"))
-      (do ((i 0 (+ i 1)))
-	  ((= i nhx))
-	(set! y (* 16.0 (- y (floor y))))
-	(set! (chx i) (hx (floor y))))
-      chx))
-  
-  (define expm
-    (let* ((ntp 25)
-	   (tp1 0)
-	   (tp (make-vector ntp)))
-      (lambda (p ak)
-	;; expm = 16^p mod ak.  This routine uses the left-to-right binary exponentiation scheme.
-	
-	;; If this is the first call to expm, fill the power of two table tp.
-	(if (= tp1 0)
-	    (begin
-	      (set! tp1 1)
-	      (set! (tp 0) 1.0)
-	      (do ((i 1 (+ i 1)))
-		  ((= i ntp))
-		(set! (tp i) (* 2.0 (tp (- i 1)))))))
-	
-	(if (= ak 1.0)
-	    0.0
-	    (let ((pl -1))
-	      ;;  Find the greatest power of two less than or equal to p.
-	      (do ((i 0 (+ i 1)))
-		  ((or (not (= pl -1)) 
-		       (= i ntp)))
-		(if (> (tp i) p)
-		    (set! pl i)))
-	      
-	      (if (= pl -1) (set! pl ntp))
-	      (let ((pt (tp (- pl 1)))
-		    (p1 p)
-		    (r 1.0))
-		;;  Perform binary exponentiation algorithm modulo ak.
-		
-		(do ((j 1 (+ j 1)))
-		    ((> j pl) r)
-		  (if (>= p1 pt)
-		      (begin
-			(set! r (* 16.0 r))
-			(set! r (- r (* ak (floor (/ r ak)))))
-			(set! p1 (- p1 pt))))
-		  (set! pt (* 0.5 pt))
-		  (if (>= pt 1.0)
-		      (begin
-			(set! r (* r r))
-			(set! r (- r (* ak (floor (/ r ak))))))))))))))
+    (do ((y (abs x))
+	 (hx "0123456789ABCDEF")
+	 (i 0 (+ i 1)))
+	((= i nhx) chx)
+      (set! y (* 16.0 (- y (floor y))))
+      (set! (chx i) (hx (floor y)))))
   
   (define (series m id)
     ;; This routine evaluates the series  sum_k 16^(id-k)/(8*k+m) using the modular exponentiation technique.
-    (let ((eps 1e-17)
+    
+    (let ((expm (let ((ntp 25))
+		  (let ((tp1 0)
+			(tp (make-vector ntp)))
+		    (lambda (p ak)
+		      ;; expm = 16^p mod ak.  This routine uses the left-to-right binary exponentiation scheme.
+		      
+		      ;; If this is the first call to expm, fill the power of two table tp.
+		      (if (= tp1 0)
+			  (begin
+			    (set! tp1 1)
+			    (set! (tp 0) 1.0)
+			    (do ((i 1 (+ i 1)))
+				((= i ntp))
+			      (set! (tp i) (* 2.0 (tp (- i 1)))))))
+		      
+		      (if (= ak 1.0)
+			  0.0
+			  (let ((pl -1))
+			    ;;  Find the greatest power of two less than or equal to p.
+			    (do ((i 0 (+ i 1)))
+				((or (not (= pl -1)) 
+				     (= i ntp)))
+			      (if (> (tp i) p)
+				  (set! pl i)))
+			    
+			    (if (= pl -1) (set! pl ntp))
+			    (let ((pt (tp (- pl 1)))
+				  (p1 p)
+				  (r 1.0))
+			      ;;  Perform binary exponentiation algorithm modulo ak.
+			      
+			      (do ((j 1 (+ j 1)))
+				  ((> j pl) r)
+				(if (>= p1 pt)
+				    (begin
+				      (set! r (* 16.0 r))
+				      (set! r (- r (* ak (floor (/ r ak)))))
+				      (set! p1 (- p1 pt))))
+				(set! pt (* 0.5 pt))
+				(if (>= pt 1.0)
+				    (begin
+				      (set! r (* r r))
+				      (set! r (- r (* ak (floor (/ r ak)))))))))))))))
+	  (eps 1e-17)
 	  (s 0.0))
       (do ((k 0 (+ k 1)))
 	  ((= k id))
 	(let* ((ak (+ (* 8 k) m))
-	       (p (- id k))
-	       (t (expm p ak)))
+	       (t (expm (- id k) ak)))
 	  (set! s (+ s (/ t ak)))
 	  (set! s (- s (floor s)))))
       
       ;; Compute a few terms where k >= id.
-      (let ((happy #f))
-	(do ((k id (+ k 1)))
-	    ((or (> k (+ id 100)) happy) s)
-	  (let* ((ak (+ (* 8 k) m))
-		 (t (/ (expt 16.0 (- id k)) ak)))
-	    (set! happy (< t eps))
-	    (set! s (+ s t))
-	    (set! s (- s (floor s))))))))
+      (do ((happy #f)
+	   (k id (+ k 1)))
+	  ((or (> k (+ id 100)) happy) s)
+	(let ((t (/ (expt 16.0 (- id k)) (+ (* 8 k) m))))
+	  (set! happy (< t eps))
+	  (set! s (+ s t))
+	  (set! s (- s (floor s)))))))
   
   ;; id is the digit position.  Digits generated follow immediately after id.
-  (let* ((chx (make-string 17))
-	 (s1 (series 1 id))
-	 (s2 (series 4 id))
-	 (s3 (series 5 id))
-	 (s4 (series 6 id))
-	 (pid (+ (* 4.0 s1) (* -2.0 s2) (- s3) (- s4))))
-    (set! pid (+ 1.0 (- pid (floor pid))))
+  (let ((chx (make-string 17))
+	(pid (let ((s1 (series 1 id))
+		   (s2 (series 4 id))
+		   (s3 (series 5 id))
+		   (s4 (series 6 id)))
+	       (- (+ (* 4.0 s1) (* -2.0 s2)) s3 s4))))
+    (set! pid (- (+ 1.0 pid) (floor pid)))
     (ihex pid 10 chx)
     (format #t " position = ~D~% fraction = ~,15F~% hex digits =  ~S~%" id pid chx)))
   
@@ -817,31 +808,32 @@
 
 (define* (sin-nx-peak n (err 1e-12))
   ;; return the min peak amp and its location for sin(x)+sin(nx+a)
-  (let* ((size (* n 100))
-	 (incr (/ (* 2 pi) size))
-	 (peak 0.0)
-	 (location 0.0)
-	 (offset (if (= (modulo n 4) 3) 0 pi)))
-    (do ((i 0 (+ i 1))
-	 (x 0.0 (+ x incr)))
-	((= i size))
-      (let ((val (abs (+ (sin x) (sin (+ offset (* n x)))))))
-	(if (> val peak)
-	    (begin
-	      (set! peak val)
-	      (set! location x)))))
-    ;; now narrow it by zigzagging around the peak
-    (let ((x location))
-      (do ((zig-size (* incr 2) (/ zig-size 2)))
-	  ((< zig-size err))
+  (let ((size (* n 100)))
+    (let ((incr (/ (* 2 pi) size))
+	  (peak 0.0)
+	  (location 0.0)
+	  (offset (if (= (modulo n 4) 3) 0 pi)))
+      (do ((i 0 (+ i 1))
+	   (x 0.0 (+ x incr)))
+	  ((= i size))
+	(let ((val (abs (+ (sin x) (sin (+ offset (* n x)))))))
+	  (if (> val peak)
+	      (begin
+		(set! peak val)
+		(set! location x)))))
+      ;; now narrow it by zigzagging around the peak
+      (do ((x location)
+	   (zig-size (* incr 2) (/ zig-size 2)))
+	  ((< zig-size err)
+	   (list (abs (+ (sin x) (sin (+ (* n x) offset)))) x))   
 	(let ((cur (abs (+ (sin x) (sin (+ offset (* n x))))))
 	      (left (abs (+ (sin (- x zig-size)) (sin (+ (* n (- x zig-size)) offset))))))
 	  (if (< left cur)
 	      (let ((right (abs (+ (sin (+ x zig-size)) (sin (+ (* n (+ x zig-size)) offset))))))
 		(if (> right cur)
 		    (set! x (+ x zig-size))))
-	      (set! x (- x zig-size)))))
-      (list (abs (+ (sin x) (sin (+ (* n x) offset)))) x))))
+	      (set! x (- x zig-size))))))))
+	
 
 ;;; --------------------------------------------------------------------------------
 
